import * as _versini_ui_private_dist_utilities from '@versini/ui-private/dist/utilities';
import { SpacingProps } from '@versini/ui-private/dist/utilities';
import * as React$1 from 'react';
import React__default from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';
import * as _floating_ui_react from '@floating-ui/react';

declare const Anchor: React__default.ForwardRefExoticComponent<{
    noNewWindowIcon?: boolean;
} & {
    children: React__default.ReactNode;
    disabled?: boolean;
    noTruncate?: boolean;
    onClick?: React__default.MouseEventHandler<HTMLButtonElement>;
    variant?: "primary" | "secondary" | "danger";
} & {
    className?: string;
    focusMode?: "dark" | "light" | "system" | "alt-system";
    fullWidth?: boolean;
    mode?: "dark" | "light" | "system" | "alt-system";
    noBorder?: boolean;
    noInternalClick?: boolean;
    raw?: boolean;
    size?: "small" | "medium" | "large";
} & _versini_ui_private_dist_utilities.SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.AnchorHTMLAttributes<HTMLAnchorElement> & React__default.RefAttributes<HTMLAnchorElement>>;

type BubbleProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * Whether or not to show a "copy/paste" icon next to the Bubble.
	 */
	copyToClipboard?: boolean | string | ((text: any) => void);
	/**
	 * The type of focus for the Copy Button. This will change the color
	 * of the focus ring around the Button.
	 */
	copyToClipboardFocusMode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * The mode of Copy Button. This will change the color of the Button.
	 */
	copyToClipboardMode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * Object depicting the extra rows for the Bubble.
	 * @example
	 * ```tsx
	 * <Bubble
	 * 	footer={{
	 * 		"Sent": "12:00 PM",
	 * 		"Delivered": "12:01 PM",
	 * 		"Read": "12:02 PM",
	 * 	}}
	 * >Hello World</Bubble>
	 * ```
	 */
	footer?: {
		[key: string]: string | number | undefined | null;
	};
	/**
	 * The type of Bubble. This will change the color of the Bubble
	 * as well as the chevron location.
	 */
	kind?: "left" | "right";
	/**
	 * Same as "footer" but accepts raw JSX.
	 */
	rawFooter?: React.ReactNode;
} & SpacingProps;

declare const Bubble: ({ children, kind, className, footer, rawFooter, copyToClipboard, copyToClipboardFocusMode, copyToClipboardMode, spacing, }: BubbleProps) => react_jsx_runtime.JSX.Element;

declare const Button: React__default.ForwardRefExoticComponent<{
    children: React__default.ReactNode;
    disabled?: boolean;
    noTruncate?: boolean;
    onClick?: React__default.MouseEventHandler<HTMLButtonElement>;
    variant?: "primary" | "secondary" | "danger";
} & {
    className?: string;
    focusMode?: "dark" | "light" | "system" | "alt-system";
    fullWidth?: boolean;
    mode?: "dark" | "light" | "system" | "alt-system";
    noBorder?: boolean;
    noInternalClick?: boolean;
    raw?: boolean;
    size?: "small" | "medium" | "large";
} & _versini_ui_private_dist_utilities.SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.RefAttributes<HTMLButtonElement>>;

declare const ButtonIcon: React__default.ForwardRefExoticComponent<{
    children: React__default.ReactNode;
    align?: "left" | "right" | "center";
    label?: string;
    labelLeft?: string;
    labelRight?: string;
    noBackground?: boolean;
} & {
    className?: string;
    focusMode?: "dark" | "light" | "system" | "alt-system";
    fullWidth?: boolean;
    mode?: "dark" | "light" | "system" | "alt-system";
    noBorder?: boolean;
    noInternalClick?: boolean;
    raw?: boolean;
    size?: "small" | "medium" | "large";
} & _versini_ui_private_dist_utilities.SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.RefAttributes<HTMLButtonElement>>;

type CardProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * If the header prop is not provided, the Card must be
	 * described via aria-labelledby.
	 */
	"aria-labelledby"?: string;
	/**
	 * CSS class(es) to add to the body.
	 */
	bodyClassName?: string;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * If true, the card will be smaller.
	 */
	compact?: boolean;
	/**
	 * The content to render in the footer.
	 */
	footer?: React.ReactNode;
	/**
	 * CSS class(es) to add to the footer.
	 */
	footerClassName?: string;
	/**
	 * The content to render in the header.
	 */
	header?: React.ReactNode;
	/**
	 * CSS class(es) to add to the header.
	 */
	headerClassName?: string;
	/**
	 * The mode of Card. This will change the color of the Card.
	 */
	mode?: "darker" | "dark" | "light" | "system" | "alt-system";
	/**
	 * Whether or not to render the Card with a border.
	 * @default false
	 */
	noBorder?: boolean;
} & SpacingProps;

declare const Card: ({ header, headerClassName, footer, footerClassName, children, className, bodyClassName, "aria-labelledby": ariaLabelledby, spacing, mode, compact, noBorder, ...otherProps }: CardProps) => react_jsx_runtime.JSX.Element;

type FooterProps = {
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * The type of Footer. This will change the color of the Footer.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * Whether or not to render the Footer with margins.
	 * @default false
	 */
	noMargins?: boolean;
	/**
	 * Whether or not to render the Footer component with no styles.
	 * @default false
	 */
	raw?: boolean;
	/**
	 * The content to render in the first row.
	 */
	row1?: React.ReactNode;
	/**
	 * The content to render in the second row.
	 */
	row2?: React.ReactNode;
} & SpacingProps;

declare const Footer: ({ className, mode, row1, row2, noMargins, spacing, raw, }: FooterProps) => react_jsx_runtime.JSX.Element;

type HeaderProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * The mode of Header. This will change the background color.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * Whether or not to render the Header component with colors.
	 */
	noColors?: boolean;
	/**
	 * Whether or not to render the Header component with no styles.
	 * @default false
	 */
	raw?: boolean;
} & SpacingProps;

declare const Header: ({ children, className, raw, spacing, mode, noColors, }: HeaderProps) => react_jsx_runtime.JSX.Element;

type MainProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * Whether or not to render the Main component with no styles.
	 * @default false
	 */
	raw?: boolean;
} & SpacingProps;

declare const Main: ({ children, className, raw, spacing, }: MainProps) => react_jsx_runtime.JSX.Element;

declare const Menu: React__default.ForwardRefExoticComponent<Omit<{
    trigger: React__default.ReactNode;
    children?: React__default.ReactNode;
    defaultPlacement?: _floating_ui_react.Placement;
    focusMode?: "dark" | "light" | "system" | "alt-system";
    mode?: "dark" | "light" | "system" | "alt-system";
    label?: string;
    onOpenChange?: (open: boolean) => void;
} & _versini_ui_private_dist_utilities.SpacingProps & React__default.HTMLProps<HTMLButtonElement>, "ref"> & React__default.RefAttributes<HTMLButtonElement>>;

type MenuItemProps = {
	/**
	 * The label to use for the menu item.
	 */
	label: string;
	/**
	 * Whether or not the menu item is disabled.
	 * @default false
	 */
	disabled?: boolean;
	/**
	 * A React component of type Icon to be placed on the left of the label.
	 */
	icon?: React__default.ReactNode;
};

type MenuSeparatorProps = React__default.HTMLAttributes<HTMLDivElement>;

declare const MenuItem: React$1.ForwardRefExoticComponent<MenuItemProps & React$1.ButtonHTMLAttributes<HTMLButtonElement> & React$1.RefAttributes<HTMLButtonElement>>;
declare const MenuSeparator: ({ className, ...props }: MenuSeparatorProps) => react_jsx_runtime.JSX.Element;

type PanelProps = {
	/**
	 * Class name to apply to the Panel - this will ONLY override the default width styles.
	 */
	className?: string;
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * Callback fired when the component is opened or closed.
	 * @param open whether or not the menu is open
	 */
	onOpenChange: (open: boolean) => void;
	/**
	 * Whether or not to open the component..
	 * @default false
	 */
	open: boolean;
	/**
	 * The title to use for the panel.
	 */
	title: string;
	/**
	 * The type of Panel border.
	 */
	borderMode?: "dark" | "light";
	/**
	 * The content to render in the footer.
	 */
	footer?: React.ReactNode;
	/**
	 * The type of Panel. This will change the layout of the Panel.
	 */
	kind?: "panel" | "messagebox";
};

declare const Panel: ({ open, onOpenChange, title, children, footer, borderMode, kind, className, }: PanelProps) => react_jsx_runtime.JSX.Element;

type PillProps = {
	/**
	 * Content of the Pill.
	 */
	label: string;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * Hidden label adjacent to the pill text to provide added
	 * context for screen reader users, ideally no more
	 * than 2-3 words.
	 */
	description?: string;
	/**
	 * Theme of the Pill.
	 * @default "information"
	 */
	variant?: "information" | "warning" | "error" | "success";
} & SpacingProps;

declare const Pill: ({ label, className, variant, description, spacing, }: PillProps) => react_jsx_runtime.JSX.Element;

type SpinnerProps = {
	/**
	 * The mode of spinner to render. This will change the color of the spinner.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * A ref to the spinner element.
	 */
	spinnerRef?: React.RefObject<HTMLDivElement>;
	/**
	 * The type of spinner to render. This will change the layout of the spinner.
	 */
	type?: "circle" | "dots";
} & SpacingProps;

declare const Spinner: ({ spinnerRef, mode, type, spacing, }: SpinnerProps) => react_jsx_runtime.JSX.Element;

declare const TableCellSortDirections: {
    ASC: string;
    DESC: string;
};

type TableProps = {
	/**
	 * This attribute defines the caption (or title) of a table.
	 */
	caption?: React__default.ReactNode;
	/**
	 * If true, the table will be smaller.
	 */
	compact?: boolean;
	/**
	 * The max height of the table. It follows the CSS max-height property.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	maxHeight?: string;
	/**
	 * The mode of table. It defines the color of the table.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * If true, the table footer will be sticky.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	stickyFooter?: boolean;
	/**
	 * If true, the table header will be sticky.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	stickyHeader?: boolean;
	/**
	 * This attribute defines an alternative text that summarizes
	 * the content of the table. It is not visible but will be
	 * read out loud by screen readers to represent the table.
	 */
	summary?: string;
	/**
	 * CSS class to apply to the table wrapper.
	 */
	wrapperClassName?: string;
} & SpacingProps &
	React__default.HTMLAttributes<HTMLTableElement>;

type TableRowProps = React__default.HTMLAttributes<HTMLTableRowElement>;
type TableBodyProps = React__default.HTMLAttributes<HTMLTableSectionElement>;
type TableHeadProps = React__default.HTMLAttributes<HTMLTableSectionElement>;

type TableCellProps = {
	/**
	 * The type of cell.
	 * @default "td"
	 */
	component?: "td" | "th";
} & React__default.ThHTMLAttributes<HTMLTableCellElement> &
	React__default.TdHTMLAttributes<HTMLTableCellElement>;

type TableCellSortProps = {
	/**
	 * Unique identifier for the cell. This string will have to be onClick
	 * handler to sort on this particular cell.
	 */
	cellId: string;
	/**
	 * The label of the cell.
	 */
	children: string;
	/**
	 * The handler to be called when the cell is clicked.
	 */
	onClick: (event: React__default.MouseEvent<unknown>) => void;
	/**
	 * The direction of the sort.
	 */
	sortDirection:
		| typeof TableCellSortDirections.ASC
		| typeof TableCellSortDirections.DESC
		| false;
	/**
	 * The cellId that is currently sorted.
	 */
	sortedCell: string;
	/**
	 * Whether to align the cell content to the left, center, or right.
	 */
	align?: "left" | "center" | "right";
	/**
	 * The type of cell.
	 * @default "td"
	 */
	component?: "td" | "th";
	/**
	 * Pass through to the underlying ButtonIcon.
	 * The type of focus for the Button. This will change the color
	 * of the focus ring around the Button.
	 */
	focusMode?: "system" | "light" | "dark" | "alt-system";
	/**
	 * Pass through to the underlying ButtonIcon.
	 * The mode of Button. This will change the color of the Button.
	 */
	mode?: "system" | "light" | "dark" | "alt-system";
} & React__default.ThHTMLAttributes<HTMLTableCellElement> &
	React__default.TdHTMLAttributes<HTMLTableCellElement>;

declare const Table: ({ children, mode, caption, compact, summary, className, wrapperClassName, maxHeight, stickyHeader, stickyFooter, spacing, ...otherProps }: TableProps) => react_jsx_runtime.JSX.Element;
declare const TableHead: ({ children, className, ...otherProps }: TableHeadProps) => react_jsx_runtime.JSX.Element;
declare const TableFooter: ({ children, className, ...otherProps }: TableHeadProps) => react_jsx_runtime.JSX.Element;
declare const TableBody: ({ children, ...otherProps }: TableBodyProps) => react_jsx_runtime.JSX.Element;
declare const TableRow: ({ children, className, ...otherProps }: TableRowProps) => react_jsx_runtime.JSX.Element;
declare const TableCell: ({ children, component, className, ...otherProps }: TableCellProps) => react_jsx_runtime.JSX.Element;
declare const TableCellSort: ({ align, children, className, component, focusMode, mode, onClick, sortDirection, sortedCell, cellId, ...otherProps }: TableCellSortProps) => react_jsx_runtime.JSX.Element;

export { Anchor, Bubble, Button, ButtonIcon, Card, Footer, Header, Main, Menu, MenuItem, MenuSeparator, Panel, Pill, Spinner, Table, TableBody, TableCell, TableCellSort, TableCellSortDirections, TableFooter, TableHead, TableRow };
